# Nebula Cert Python

> Manager nebula certificates from Python

## Prerequisite

This library expects the `nebula-cert` to be installed on host system.

You can download [latest binaries from github](https://github.com/slackhq/nebula/releases/latest):
  - [Windows (amd64)](https://github.com/slackhq/nebula/releases/download/v1.6.1/nebula-windows-amd64.zip)
  - [Linux (amd64)](https://github.com/slackhq/nebula/releases/download/v1.6.1/nebula-linux-amd64.tar.gz)
  - [Linux (arm64)](https://github.com/slackhq/nebula/releases/download/v1.6.1/nebula-linux-arm64.tar.gz)
  - [Linux (armv7)](https://github.com/slackhq/nebula/releases/download/v1.6.1/nebula-linux-arm-7.tar.gz)

## Quick start

Run `python -m nebula.cert` or `pync` to get started
